@@ -1,6 +1,5 @@
 use crate::bounding_volume::{HasBoundingVolume, AABB};
-use crate::math::{Isometry, Point};
-use crate::num::Bounded;
+use crate::math::{Isometry, Point, Vector};
 use crate::shape::Plane;
 use na::{self, RealField};
 
@@ -14,7 +13,9 @@ impl<N: RealField + Copy> HasBoundingVolume<N, AABB<N>> for Plane<N> {
     fn local_bounding_volume(&self) -> AABB<N> {
         // We divide by 2.0  so that we can still make some operations with it (like loosening)
         // without breaking the box.
-        let max = Point::max_value() * na::convert(0.5f64);
+        let max = Point::from(Vector::repeat(
+            N::max_value().unwrap() * na::convert(0.5f64),
+        ));
 
         AABB::new(-max, max)
     }
