@@ -3,7 +3,7 @@ use crate::math::Isometry;
 use crate::shape::TriMesh;
 use na::{self, RealField};
 
-impl<N: RealField> HasBoundingVolume<N, AABB<N>> for TriMesh<N> {
+impl<N: RealField + Copy> HasBoundingVolume<N, AABB<N>> for TriMesh<N> {
     #[inline]
     fn bounding_volume(&self, m: &Isometry<N>) -> AABB<N> {
         self.aabb().transform_by(m)
