@@ -3,7 +3,7 @@ use crate::math::Isometry;
 use crate::shape::Compound;
 use na::RealField;
 
-impl<N: RealField> HasBoundingVolume<N, BoundingSphere<N>> for Compound<N> {
+impl<N: RealField + Copy> HasBoundingVolume<N, BoundingSphere<N>> for Compound<N> {
     #[inline]
     fn bounding_volume(&self, m: &Isometry<N>) -> BoundingSphere<N> {
         self.aabb().bounding_sphere().transform_by(m)
