@@ -2,7 +2,9 @@ use crate::pipeline::object::CollisionObjectSet;
 use na::RealField;
 
 /// A signal handler for contact detection.
-pub trait BroadPhasePairFilter<N: RealField + Copy, Set: CollisionObjectSet<N>>: Send + Sync {
+pub trait BroadPhasePairFilter<N: RealField + Copy, Set: CollisionObjectSet<N>>:
+    Send + Sync
+{
     /// Activate an action for when two objects start or stop to be close to each other.
     fn is_pair_valid(
         &self,
