@@ -6,14 +6,14 @@ use na::RealField;
 // FIXME: add a point cost fn.
 
 /// Spatial partitioning structure visitor collecting nodes that may contain a given point.
-pub struct PointInterferencesCollector<'a, N: 'a + RealField, T: 'a> {
+pub struct PointInterferencesCollector<'a, N: 'a + RealField + Copy, T: 'a> {
     /// Point to be tested.
     pub point: &'a Point<N>,
     /// The data contained by the nodes which bounding volume contain `self.point`.
     pub collector: &'a mut Vec<T>,
 }
 
-impl<'a, N: RealField, T> PointInterferencesCollector<'a, N, T> {
+impl<'a, N: RealField + Copy, T> PointInterferencesCollector<'a, N, T> {
     /// Creates a new `PointInterferencesCollector`.
     #[inline]
     pub fn new(
@@ -29,7 +29,7 @@ impl<'a, N: RealField, T> PointInterferencesCollector<'a, N, T> {
 
 impl<'a, N, T, BV> Visitor<T, BV> for PointInterferencesCollector<'a, N, T>
 where
-    N: RealField,
+    N: RealField + Copy,
     T: Clone,
     BV: PointQuery<N>,
 {
