@@ -3,7 +3,7 @@ use crate::procedural::TriMesh;
 use crate::shape::Triangle;
 use simba::scalar::RealField;
 
-impl<N: RealField> ToTriMesh<N> for Triangle<N> {
+impl<N: RealField + Copy> ToTriMesh<N> for Triangle<N> {
     type DiscretizationParameter = ();
 
     fn to_trimesh(&self, _: ()) -> TriMesh<N> {
